[ARVADOS] created: 560ecc87e4eace1ff7ad4f68ac3a4054eb715423

Git user git at public.curoverse.com
Tue Aug 1 15:32:25 EDT 2017


        at  560ecc87e4eace1ff7ad4f68ac3a4054eb715423 (commit)


commit 560ecc87e4eace1ff7ad4f68ac3a4054eb715423
Author: Tom Clegg <tom at curoverse.com>
Date:   Tue Aug 1 15:31:45 2017 -0400

    12024: Build new Go packages when the vendor bundle changes.
    
    Arvados-DCO-1.1-Signed-off-by: Tom Clegg <tom at curoverse.com>

diff --git a/build/run-library.sh b/build/run-library.sh
index ae5ad6d..ee6c377 100755
--- a/build/run-library.sh
+++ b/build/run-library.sh
@@ -108,12 +108,19 @@ package_go_binary() {
     local version="$(version_from_git)"
     local timestamp="$(timestamp_from_git)"
 
-    # If the command imports anything from the Arvados SDK, bump the
-    # version number and build a new package whenever the SDK changes.
+    # Update the version number and build a new package if the vendor
+    # bundle has changed, or the command imports anything from the
+    # Arvados SDK and the SDK has changed.
+    declare -a checkdirs=(vendor)
     if grep -qr git.curoverse.com/arvados .; then
-        cd "$GOPATH/src/git.curoverse.com/arvados.git/sdk/go"
-        if [[ $(timestamp_from_git) -gt "$timestamp" ]]; then
+        checkdirs+=(sdk/go)
+    fi
+    for dir in ${checkdirs[@]}; do
+        cd "$GOPATH/src/git.curoverse.com/arvados.git/$dir"
+        ts="$(timestamp_from_git)"
+        if [[ "$ts" -gt "$timestamp" ]]; then
             version=$(version_from_git)
+            timestamp="$ts"
         fi
     fi
 

-----------------------------------------------------------------------


hooks/post-receive
-- 




More information about the arvados-commits mailing list